import { UUID } from '#application/types'
import CharacterTypeRepository from '#repositories/characterTypeRepository'
import { BaseEvent } from '#application/base/baseEvent'

interface IPayload {
  id: UUID
}

export default class CharacterTypeDeleteEvent extends BaseEvent {
  public listen(): void {
    this.socket.on('gm:characterType:remove', this.handleEvent.bind(this))
  }

  private async handleEvent(data: IPayload, callback: (response: boolean) => void): Promise<void> {
    try {
      if (!(await this.isCharacterGM())) return

      const characterType = await CharacterTypeRepository.getById(data.id)
      if (!characterType) return callback(false)

      await characterType.delete()
      return callback(true)
    } catch (error) {
      this.logger.error(`Error deleting character type ${data.id}: ${error instanceof Error ? error.message : String(error)}`)
      return callback(false)
    }
  }
}
