import { BaseEvent } from '#application/base/baseEvent'
import { UUID } from '#application/types'
import { Sprite } from '#entities/sprite'
import CharacterRepository from '#repositories/characterRepository'
import SpriteRepository from '#repositories/spriteRepository'

interface CopyPayload {
  id: UUID
}

export default class SpriteCopyEvent extends BaseEvent {
  public listen(): void {
    this.socket.on('gm:sprite:copy', this.handleEvent.bind(this))
  }

  private async handleEvent(payload: CopyPayload, callback: (success: boolean) => void): Promise<void> {
    try {
      if (!(await this.isCharacterGM())) return

      const sourceSprite = await SpriteRepository.getById(payload.id)

      if (!sourceSprite) {
        throw new Error('Source sprite not found')
      }

      const newSprite = new Sprite()
      await newSprite.setName(`${sourceSprite.getName()} (Copy)`).setSpriteActions(sourceSprite.getSpriteActions()).save()

      callback(true)
    } catch (error) {
      this.logger.error(`Error copying sprite:`, String(error))
      callback(false)
    }
  }
}
